package com.hw.mes.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.hw.common.security.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.mes.domain.MesBaseSupplierInfo;
import com.hw.mes.service.IMesBaseSupplierInfoService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 物料供应商信息Controller
 * 
 * @author Yinq
 * @date 2024-01-24
 */
@RestController
@RequestMapping("/supplierInfo")
public class MesBaseSupplierInfoController extends BaseController
{
    @Autowired
    private IMesBaseSupplierInfoService mesBaseSupplierInfoService;

    /**
     * 查询物料供应商信息列表
     */
    @RequiresPermissions("mes:supplierInfo:list")
    @GetMapping("/list")
    public TableDataInfo list(MesBaseSupplierInfo mesBaseSupplierInfo)
    {
        startPage();
        List<MesBaseSupplierInfo> list = mesBaseSupplierInfoService.selectMesBaseSupplierInfoList(mesBaseSupplierInfo);
        return getDataTable(list);
    }

    /**
     * 导出物料供应商信息列表
     */
    @RequiresPermissions("mes:supplierInfo:export")
    @Log(title = "物料供应商信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MesBaseSupplierInfo mesBaseSupplierInfo)
    {
        List<MesBaseSupplierInfo> list = mesBaseSupplierInfoService.selectMesBaseSupplierInfoList(mesBaseSupplierInfo);
        ExcelUtil<MesBaseSupplierInfo> util = new ExcelUtil<MesBaseSupplierInfo>(MesBaseSupplierInfo.class);
        util.exportExcel(response, list, "物料供应商信息数据");
    }

    /**
     * 获取物料供应商信息详细信息
     */
    @RequiresPermissions("mes:supplierInfo:query")
    @GetMapping(value = "/{supplierId}")
    public AjaxResult getInfo(@PathVariable("supplierId") Long supplierId)
    {
        return success(mesBaseSupplierInfoService.selectMesBaseSupplierInfoBySupplierId(supplierId));
    }

    /**
     * 新增物料供应商信息
     */
    @RequiresPermissions("mes:supplierInfo:add")
    @Log(title = "物料供应商信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MesBaseSupplierInfo mesBaseSupplierInfo)
    {
        mesBaseSupplierInfo.setCreateBy(SecurityUtils.getLoginUser().getUsername());
        return toAjax(mesBaseSupplierInfoService.insertMesBaseSupplierInfo(mesBaseSupplierInfo));
    }

    /**
     * 修改物料供应商信息
     */
    @RequiresPermissions("mes:supplierInfo:edit")
    @Log(title = "物料供应商信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MesBaseSupplierInfo mesBaseSupplierInfo)
    {
        mesBaseSupplierInfo.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
        return toAjax(mesBaseSupplierInfoService.updateMesBaseSupplierInfo(mesBaseSupplierInfo));
    }

    /**
     * 删除物料供应商信息
     */
    @RequiresPermissions("mes:supplierInfo:remove")
    @Log(title = "物料供应商信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{supplierIds}")
    public AjaxResult remove(@PathVariable Long[] supplierIds)
    {
        return toAjax(mesBaseSupplierInfoService.deleteMesBaseSupplierInfoBySupplierIds(supplierIds));
    }
}
